@@ -124,7 +124,7 @@ class AbstractCircuit:
                 split=split,
                 mpo=mpo,
                 ir_dict=gate_dict,
-            )  # type: ignore
+            )
 
         return apply
 
@@ -150,7 +150,7 @@ class AbstractCircuit:
             if name is not None:
                 localname = name
             else:
-                localname = defaultname  # type: ignore
+                localname = defaultname
 
             # split = None
             gate = gatef()
@@ -353,12 +353,12 @@ class AbstractCircuit:
         if "nqubits" not in circuit_params:
             nqubits = 0
             for d in qir:
-                if max(d["index"]) > nqubits:  # type: ignore
-                    nqubits = max(d["index"])  # type: ignore
+                if max(d["index"]) > nqubits:
+                    nqubits = max(d["index"])
             nqubits += 1
             circuit_params["nqubits"] = nqubits
 
-        c = cls(**circuit_params)  # type: ignore
+        c = cls(**circuit_params)
         c = cls._apply_qir(c, qir)
         return c
 
@@ -368,13 +368,13 @@ class AbstractCircuit:
     ) -> "AbstractCircuit":
         for d in qir:
             if "parameters" not in d:
-                c.apply_general_gate_delayed(d["gatef"], d["name"], mpo=d["mpo"])(  # type: ignore
-                    c, *d["index"], split=d["split"]  # type: ignore
+                c.apply_general_gate_delayed(d["gatef"], d["name"], mpo=d["mpo"])(
+                    c, *d["index"], split=d["split"]
                 )
             else:
-                c.apply_general_variable_gate_delayed(d["gatef"], d["name"], mpo=d["mpo"])(  # type: ignore
-                    c, *d["index"], **d["parameters"], split=d["split"]  # type: ignore
-                )
+                c.apply_general_variable_gate_delayed(
+                    d["gatef"], d["name"], mpo=d["mpo"]
+                )(c, *d["index"], **d["parameters"], split=d["split"])
         return c
 
     def inverse(
@@ -400,16 +400,16 @@ class AbstractCircuit:
         if "nqubits" not in circuit_params:
             circuit_params["nqubits"] = self._nqubits
 
-        c = type(self)(**circuit_params)  # type: ignore
+        c = type(self)(**circuit_params)
         for d in reversed(self._qir):
             if "parameters" not in d:
-                self.apply_general_gate_delayed(d["gatef"].adjoint(), d["name"], mpo=d["mpo"])(  # type: ignore
-                    c, *d["index"], split=d["split"]  # type: ignore
-                )
+                self.apply_general_gate_delayed(
+                    d["gatef"].adjoint(), d["name"], mpo=d["mpo"]
+                )(c, *d["index"], split=d["split"])
             else:
-                self.apply_general_variable_gate_delayed(d["gatef"].adjoint(), d["name"], mpo=d["mpo"])(  # type: ignore
-                    c, *d["index"], **d["parameters"], split=d["split"]  # type: ignore
-                )
+                self.apply_general_variable_gate_delayed(
+                    d["gatef"].adjoint(), d["name"], mpo=d["mpo"]
+                )(c, *d["index"], **d["parameters"], split=d["split"])
 
         return c
 
@@ -509,6 +509,17 @@ class AbstractCircuit:
         qir = self.to_qir()
         return qir2qiskit(qir, n=self._nqubits)
 
+    def to_openqasm(self, **kws: Any) -> str:
+        """
+        transform circuit to openqasm via qiskit circuit,
+        see https://qiskit.org/documentation/stubs/qiskit.circuit.QuantumCircuit.qasm.html
+        for usage on possible options for ``kws``
+
+        :return: circuit representation in openqasm format
+        :rtype: str
+        """
+        return self.to_qiskit().qasm(**kws)  # type: ignore
+
     def draw(self, **kws: Any) -> Any:
         """
         Visualise the circuit.
@@ -600,6 +611,90 @@ class AbstractCircuit:
                 json.dump(tcqasm, f)
         return json.dumps(tcqasm)
 
+    @classmethod
+    def from_qsim_file(
+        cls, file: str, circuit_params: Optional[Dict[str, Any]] = None
+    ) -> "AbstractCircuit":
+        with open(file, "r") as f:
+            lines = f.readlines()
+        if circuit_params is None:
+            circuit_params = {}
+        if "nqubits" not in circuit_params:
+            circuit_params["nqubits"] = int(lines[0])
+
+        c = cls(**circuit_params)
+        c = cls._apply_qsim(c, lines)
+        return c
+
+    @staticmethod
+    def _apply_qsim(c: "AbstractCircuit", qsim_str: List[str]) -> "AbstractCircuit":
+        def _convert_ints_and_floats(x: str) -> Union[str, int, float]:
+            try:
+                return int(x)
+            except ValueError:
+                pass
+
+            try:
+                return float(x)
+            except ValueError:
+                pass
+
+            return x.lower()
+
+        qsim_gates = [
+            tuple(map(_convert_ints_and_floats, line.strip().split(" ")))
+            for line in qsim_str[1:]
+            if line
+        ]
+        # https://github.com/quantumlib/qsim/blob/master/docs/input_format.md
+        # https://github.com/jcmgray/quimb/blob/master/quimb/tensor/circuit.py#L241
+        for gate in qsim_gates:
+            if gate[1] == "h":
+                getattr(c, "H")(gate[2])
+            elif gate[1] == "x":
+                getattr(c, "X")(gate[2])
+            elif gate[1] == "y":
+                getattr(c, "Y")(gate[2])
+            elif gate[1] == "z":
+                getattr(c, "Z")(gate[2])
+            elif gate[1] == "s":
+                getattr(c, "PHASE")(gate[2], theta=np.pi / 2)
+            elif gate[1] == "t":
+                getattr(c, "PHASE")(gate[2], theta=np.pi / 4)
+            elif gate[1] == "x_1_2":
+                getattr(c, "RX")(gate[2], theta=np.pi / 2)
+            elif gate[1] == "y_1_2":
+                getattr(c, "RY")(gate[2], theta=np.pi / 2)
+            elif gate[1] == "z_1_2":
+                getattr(c, "RZ")(gate[2], theta=np.pi / 2)
+            elif gate[1] == "w_1_2":
+                getattr(c, "U")(gate[2], theta=np.pi / 2, phi=-np.pi / 4, lbd=np.pi / 4)
+            elif gate[1] == "hz_1_2":
+                getattr(c, "WROOT")(gate[2])
+            elif gate[1] == "cnot":
+                getattr(c, "CNOT")(gate[2], gate[3])
+            elif gate[1] == "cx":
+                getattr(c, "CX")(gate[2], gate[3])
+            elif gate[1] == "cy":
+                getattr(c, "CY")(gate[2], gate[3])
+            elif gate[1] == "cz":
+                getattr(c, "CZ")(gate[2], gate[3])
+            elif gate[1] == "is" or gate[1] == "iswap":
+                getattr(c, "ISWAP")(gate[2], gate[3])
+            elif gate[1] == "rx":
+                getattr(c, "RX")(gate[2], theta=gate[3])
+            elif gate[1] == "ry":
+                getattr(c, "RY")(gate[2], theta=gate[3])
+            elif gate[1] == "rz":
+                getattr(c, "RZ")(gate[2], theta=gate[3])
+            elif gate[1] == "fs" or gate[1] == "fsim":
+                i, j, theta, phi = gate[2:]
+                getattr(c, "ISWAP")(i, j, theta=-theta)  # type: ignore
+                getattr(c, "CPHASE")(i, j, theta=-phi)  # type: ignore
+            else:
+                raise NotImplementedError
+        return c
+
     @classmethod
     def from_json(
         cls, jsonstr: str, circuit_params: Optional[Dict[str, Any]] = None
@@ -690,7 +785,9 @@ class AbstractCircuit:
         :rtype: Tensor
         """
         return self.general_kraus(  # type: ignore
-            [np.array([[1.0, 0], [0, 0]]), np.array([[0, 0], [0, 1]])], index, name="measure"  # type: ignore
+            [np.array([[1.0, 0], [0, 0]]), np.array([[0, 0], [0, 1]])],
+            index,
+            name="measure",
         )
 
     cond_measure = cond_measurement
