@@ -389,6 +389,13 @@ class JaxBackend(jax_backend.JaxBackend, ExtendedBackend):  # type: ignore
     def solve(self, A: Tensor, b: Tensor, assume_a: str = "gen") -> Tensor:  # type: ignore
         return jsp.linalg.solve(A, b, assume_a)
 
+    def searchsorted(self, a: Tensor, v: Tensor, side: str = "left") -> Tensor:
+        if not self.is_tensor(a):
+            a = self.convert_to_tensor(a)
+        if not self.is_tensor(v):
+            v = self.convert_to_tensor(v)
+        return jnp.searchsorted(a, v, side)
+
     def tree_map(self, f: Callable[..., Any], *pytrees: Any) -> Any:
         return libjax.tree_map(f, *pytrees)
 
@@ -401,12 +408,12 @@ class JaxBackend(jax_backend.JaxBackend, ExtendedBackend):  # type: ignore
     def from_dlpack(self, a: Any) -> Tensor:
         import jax.dlpack
 
-        return jax.dlpack.from_dlpack(a)  # type: ignore
+        return jax.dlpack.from_dlpack(a)
 
     def to_dlpack(self, a: Tensor) -> Any:
         import jax.dlpack
 
-        return jax.dlpack.to_dlpack(a)  # type: ignore
+        return jax.dlpack.to_dlpack(a)
 
     def set_random_state(
         self, seed: Optional[Union[int, PRNGKeyArray]] = None, get_only: bool = False
@@ -440,7 +447,7 @@ class JaxBackend(jax_backend.JaxBackend, ExtendedBackend):  # type: ignore
             g = getattr(self, "g", None)
         try:
             key, subkey = libjax.random.split(g)
-        except libjax._src.errors.UnexpectedTracerError:
+        except libjax.errors.UnexpectedTracerError:
             self.set_random_state()
             g = getattr(self, "g", None)
             key, subkey = libjax.random.split(g)
@@ -462,7 +469,7 @@ class JaxBackend(jax_backend.JaxBackend, ExtendedBackend):  # type: ignore
             g = getattr(self, "g", None)
         try:
             key, subkey = libjax.random.split(g)
-        except libjax._src.errors.UnexpectedTracerError:
+        except libjax.errors.UnexpectedTracerError:
             self.set_random_state()
             g = getattr(self, "g", None)
             key, subkey = libjax.random.split(g)
@@ -482,7 +489,7 @@ class JaxBackend(jax_backend.JaxBackend, ExtendedBackend):  # type: ignore
             g = getattr(self, "g", None)
         try:
             key, subkey = libjax.random.split(g)
-        except libjax._src.errors.UnexpectedTracerError:
+        except libjax.errors.UnexpectedTracerError:
             self.set_random_state()
             g = getattr(self, "g", None)
             key, subkey = libjax.random.split(g)
