@@ -283,7 +283,7 @@ class PyTorchBackend(pytorch_backend.PyTorchBackend, ExtendedBackend):  # type:
 
     def i(self, dtype: Any = None) -> Tensor:
         if not dtype:
-            dtype = getattr(torchlib, dtypestr)  # type: ignore
+            dtype = getattr(torchlib, dtypestr)
         if isinstance(dtype, str):
             dtype = getattr(torchlib, dtype)
         return torchlib.tensor(1j, dtype=dtype)
@@ -389,6 +389,13 @@ class PyTorchBackend(pytorch_backend.PyTorchBackend, ExtendedBackend):  # type:
     def solve(self, A: Tensor, b: Tensor, **kws: Any) -> Tensor:
         return torchlib.linalg.solve(A, b)
 
+    def searchsorted(self, a: Tensor, v: Tensor, side: str = "left") -> Tensor:
+        if not self.is_tensor(a):
+            a = self.convert_to_tensor(a)
+        if not self.is_tensor(v):
+            v = self.convert_to_tensor(v)
+        return torchlib.searchsorted(a, v, side=side)
+
     def reverse(self, a: Tensor) -> Tensor:
         return torchlib.flip(a, dims=(-1,))
 
