@@ -329,7 +329,7 @@ class TensorFlowBackend(tensorflow_backend.TensorFlowBackend, ExtendedBackend):
 
     def i(self, dtype: Any = None) -> Tensor:
         if not dtype:
-            dtype = getattr(tf, dtypestr)  # type: ignore
+            dtype = getattr(tf, dtypestr)
         if isinstance(dtype, str):
             dtype = getattr(tf, dtype)
         return tf.constant(1j, dtype=dtype)
@@ -434,6 +434,9 @@ class TensorFlowBackend(tensorflow_backend.TensorFlowBackend, ExtendedBackend):
             return self.reshape(x, x.shape[:-1])
         return x
 
+    def searchsorted(self, a: Tensor, v: Tensor, side: str = "left") -> Tensor:
+        return tf.searchsorted(a, v, side)
+
     def from_dlpack(self, a: Any) -> Tensor:
         return tf.experimental.dlpack.from_dlpack(a)
 
@@ -594,7 +597,7 @@ class TensorFlowBackend(tensorflow_backend.TensorFlowBackend, ExtendedBackend):
                 else:
                     args = tuple(
                         [
-                            tf.identity(arg) if i in argnums else arg  # type: ignore
+                            tf.identity(arg) if i in argnums else arg
                             for i, arg in enumerate(args)
                         ]
                     )
@@ -625,7 +628,7 @@ class TensorFlowBackend(tensorflow_backend.TensorFlowBackend, ExtendedBackend):
                 else:
                     args = tuple(
                         [
-                            tf.identity(arg) if i in argnums else arg  # type: ignore
+                            tf.identity(arg) if i in argnums else arg
                             for i, arg in enumerate(args)
                         ]
                     )
