@@ -14,6 +14,7 @@ from . import gates
 from .quantum import (
     QuOperator,
     QuVector,
+    correlation_from_samples,
     correlation_from_counts,
     measurement_counts,
     sample_int2bin,
@@ -135,7 +136,7 @@ class BaseCircuit(AbstractCircuit):
             ir_dict = gate_dict
         self._qir.append(ir_dict)
         assert len(index) == len(set(index))
-        index = tuple([i if i >= 0 else self._nqubits + i for i in index])  # type: ignore
+        index = tuple([i if i >= 0 else self._nqubits + i for i in index])
         noe = len(index)
         nq = self._nqubits
         applied = False
@@ -256,7 +257,7 @@ class BaseCircuit(AbstractCircuit):
             for e in t.edges:
                 newfront.append(edict[e])
             return newnodes, newfront
-        return self._copy(conj)  # type: ignore
+        return self._copy(conj)
 
     def expectation_before(
         self,
@@ -310,7 +311,7 @@ class BaseCircuit(AbstractCircuit):
         for j in range(nq):
             if j not in occupied:  # edge1[j].is_dangling invalid here!
                 newdang[j] ^ newdang[j + nq]
-        return nodes  # type: ignore
+        return nodes
 
     def to_qir(self) -> List[Dict[str, Any]]:
         """
@@ -506,8 +507,10 @@ class BaseCircuit(AbstractCircuit):
         self,
         batch: Optional[int] = None,
         allow_state: bool = False,
+        readout_error: Optional[Sequence[Any]] = None,
         format: Optional[str] = None,
         random_generator: Optional[Any] = None,
+        status: Optional[Tensor] = None,
     ) -> Any:
         """
         batched sampling from state or circuit tensor network directly
@@ -517,11 +520,16 @@ class BaseCircuit(AbstractCircuit):
         :param allow_state: if true, we sample from the final state
             if memory allsows, True is prefered, defaults to False
         :type allow_state: bool, optional
+        :param readout_error: readout_error, defaults to None
+        :type readout_error: Optional[Sequence[Any]]. Tensor, List, Tuple
         :param format: sample format, defaults to None as backward compatibility
             check the doc in :py:meth:`tensorcircuit.quantum.measurement_results`
         :type format: Optional[str]
         :param random_generator: random generator,  defaults to None
         :type random_generator: Optional[Any], optional
+        :param status: external randomness given by tensor uniformly from [0, 1],
+            if set, can overwrite random_generator
+        :type status: Optional[Tensor]
         :return: List (if batch) of tuple (binary configuration tensor and correponding probability)
             if the format is None, and consitent with format when given
         :rtype: Any
@@ -539,7 +547,7 @@ class BaseCircuit(AbstractCircuit):
                 r = [r]  # type: ignore
             else:
 
-                @backend.jit  # type: ignore
+                @backend.jit
                 def perfect_sampling(key: Any) -> Any:
                     backend.set_random_state(key)
                     return self.perfect_sampling()
@@ -563,22 +571,31 @@ class BaseCircuit(AbstractCircuit):
             s = self.state()  # type: ignore
             if self.is_dm is False:
                 p = backend.abs(s) ** 2
+
+                # readout error
+                if readout_error is not None:
+                    p = self.readouterror_bs(readout_error, p)
+
             else:
                 p = backend.abs(backend.diagonal(s))
-            a_range = backend.arange(2**self._nqubits)
-            if random_generator is None:
-                ch = backend.implicit_randc(a=a_range, shape=[nbatch], p=p)
-            else:
-                ch = backend.stateful_randc(
-                    random_generator, a=a_range, shape=[nbatch], p=p
-                )
+
+                # readout error
+                if readout_error is not None:
+                    p = self.readouterror_bs(readout_error, p)
+            ch = backend.probability_sample(nbatch, p, status, random_generator)
+            # if random_generator is None:
+            #     ch = backend.implicit_randc(a=a_range, shape=[nbatch], p=p)
+            # else:
+            #     ch = backend.stateful_randc(
+            #         random_generator, a=a_range, shape=[nbatch], p=p
+            #     )
             # confg = backend.mod(
             #     backend.right_shift(
             #         ch[..., None], backend.reverse(backend.arange(self._nqubits))
             #     ),
             #     2,
             # )
-            if format is None:
+            if format is None:  # for backward compatibility
                 confg = sample_int2bin(ch, self._nqubits)
                 prob = backend.gather1d(p, ch)
                 r = list(zip(confg, prob))  # type: ignore
@@ -594,6 +611,8 @@ class BaseCircuit(AbstractCircuit):
         z: Optional[Sequence[int]] = None,
         shots: Optional[int] = None,
         random_generator: Optional[Any] = None,
+        status: Optional[Tensor] = None,
+        readout_error: Optional[Sequence[Any]] = None,
         **kws: Any,
     ) -> Tensor:
         """
@@ -606,6 +625,10 @@ class BaseCircuit(AbstractCircuit):
         >>> c.rx(1, theta=np.pi/2)
         >>> c.sample_expectation_ps(x=[0], y=[1])
         -0.99999976
+        >>> readout_error = []
+        >>> readout_error.append([0.9,0.75])
+        >>> readout_error.append([0.4,0.7])
+        >>> c.sample_expectation_ps(x=[0], y=[1],readout_error = readout_error)
 
         :param x: index for Pauli X, defaults to None
         :type x: Optional[Sequence[int]], optional
@@ -616,7 +639,12 @@ class BaseCircuit(AbstractCircuit):
         :param shots: number of measurement shots, defaults to None, indicating analytical result
         :type shots: Optional[int], optional
         :param random_generator: random_generator, defaults to None
-        :type random_general: Optional[Any]
+        :type random_generator: Optional[Any]
+        :param status: external randomness given by tensor uniformly from [0, 1],
+            if set, can overwrite random_generator
+        :type status: Optional[Tensor]
+        :param readout_error: readout_error, defaults to None
+        :type readout_error: Optional[Sequence[Any]]. Tensor, List, Tuple
         :return: [description]
         :rtype: Tensor
         """
@@ -635,28 +663,90 @@ class BaseCircuit(AbstractCircuit):
         for i in y:
             c.rx(i, theta=np.pi / 2)  # type: ignore
         s = c.state()  # type: ignore
-        if c.is_dm is False:
+        if self.is_dm is False:
             p = backend.abs(s) ** 2
         else:
             p = backend.abs(backend.diagonal(s))
-        # readout error can be processed here later
-        mc = measurement_counts(
-            p,
-            counts=shots,
-            format="count_vector",
-            random_generator=random_generator,
-            jittable=True,
-            is_prob=True,
-        )
+
+        # readout error
+        if readout_error is not None:
+            p = self.readouterror_bs(readout_error, p)
+
         x = list(x)
         y = list(y)
         z = list(z)
-        r = correlation_from_counts(x + y + z, mc)
+        if shots is None:
+            mc = measurement_counts(
+                p,
+                counts=shots,
+                format="count_vector",
+                random_generator=random_generator,
+                status=status,
+                jittable=True,
+                is_prob=True,
+            )
+            r = correlation_from_counts(x + y + z, mc)
+        else:
+            mc = measurement_counts(
+                p,
+                counts=shots,
+                format="sample_bin",
+                random_generator=random_generator,
+                status=status,
+                jittable=True,
+                is_prob=True,
+            )
+            r = correlation_from_samples(x + y + z, mc, self._nqubits)
         # TODO(@refraction-ray): analytical standard deviation
         return r
 
     sexpps = sample_expectation_ps
 
+    def readouterror_bs(
+        self, readout_error: Optional[Sequence[Any]] = None, p: Optional[Any] = None
+    ) -> Tensor:
+        """Apply readout error to original probabilities of bit string and return the noisy probabilities.
+
+        :Example:
+
+        >>> readout_error = []
+        >>> readout_error.append([0.9,0.75])  # readout error for qubit 0, [p0|0,p1|1]
+        >>> readout_error.append([0.4,0.7])   # readout error for qubit 1, [p0|0,p1|1]
+
+
+        :param readout_error: list of readout error for each qubits.
+        :type readout_error: Optional[Sequence[Any]]. Tensor, List, Tuple
+        :param p: probabilities of bit string
+        :type p: Optional[Any]
+        :rtype: Tensor
+        """
+        # if isinstance(readout_error, tuple):
+        #     readout_error = list[readout_error]  # type: ignore
+
+        nqubit = len(readout_error)  # type: ignore
+        readoutlist = []
+        for i in range(nqubit):
+            readoutlist.append(
+                [
+                    [readout_error[i][0], 1 - readout_error[i][1]],  # type: ignore
+                    [1 - readout_error[i][0], readout_error[i][1]],  # type: ignore
+                ]
+            )
+        readoutlist = backend.cast(
+            backend.convert_to_tensor(readoutlist), dtype=dtypestr
+        )
+
+        ms = [Gate(readoutlist[i]) for i in range(nqubit)]
+        p = backend.cast(p, dtypestr)
+        p = Gate(backend.reshape2(p))
+        for i in range(nqubit):
+            ms[i][1] ^ p[i]
+        nodes = ms + [p]
+        r = contractor(nodes, output_edge_order=[m[0] for m in ms]).tensor
+        p = backend.reshape(r, [-1])
+
+        return backend.real(p)
+
     def replace_inputs(self, inputs: Tensor) -> None:
         """
         Replace the input state with the circuit structure unchanged.
@@ -705,7 +795,9 @@ class BaseCircuit(AbstractCircuit):
         :rtype: Tensor
         """
         return self.general_kraus(  # type: ignore
-            [np.array([[1.0, 0], [0, 0]]), np.array([[0, 0], [0, 1]])], index, name="measure"  # type: ignore
+            [np.array([[1.0, 0], [0, 0]]), np.array([[0, 0], [0, 1]])],
+            index,
+            name="measure",
         )
 
     cond_measure = cond_measurement
