@@ -873,6 +873,7 @@ def test_qir2qiskit(backend):
     c.cx(2, 3)
     c.swap(0, 1)
     c.iswap(0, 1)
+    c.iswap(1, 3, theta=-1.9)
     c.toffoli(0, 1, 2)
     c.s(1)
     c.t(1)
@@ -891,6 +892,13 @@ def test_qir2qiskit(backend):
     c.oy(4, 3)
     c.oz(4, 3)
     c.ox(3, 4)
+    c.phase(2, theta=0.3)
+    c.cphase(1, 0, theta=-1.2)
+    c.rxx(0, 2, theta=0.9)
+    c.ryy(1, 4, theta=-2.0)
+    c.rzz(1, 3, theta=0.5)
+    c.u(2, theta=0, lbd=4.6, phi=-0.3)
+    c.cu(4, 1, theta=1.2)
     c.rx(1, theta=tc.array_to_tensor(np.random.uniform()))
     c.r(5, theta=tc.array_to_tensor(np.random.uniform()))
     c.cr(
@@ -968,6 +976,7 @@ def test_qiskit2tc():
     qisc.cz(0, 1, ctrl_state=0)
     qisc.cy(0, 1, ctrl_state=0)
     qisc.cx(0, 1, ctrl_state=0)
+    qisc.u(0.3, 0.9, -1.2, 2)
     qisc.rx(np.random.uniform(), 1)
     qisc.ry(np.random.uniform(), 2)
     qisc.rz(np.random.uniform(), 3)
@@ -1008,6 +1017,14 @@ def test_batch_sample(backend):
             batch=8, allow_state=True, random_generator=tc.backend.get_random_state(42)
         )
     )
+    print(
+        c.sample(
+            batch=8,
+            allow_state=True,
+            status=np.random.uniform(size=[8]),
+            format="sample_bin",
+        )
+    )
 
 
 def test_expectation_y_bug():
@@ -1193,3 +1210,13 @@ def test_gate_count():
     assert c.gate_count(["rx", "multicontrol"]) == 2
     print(c.gate_summary())
     # {'h': 2, 'rx': 1, 'multicontrol': 1, 'toffoli': 3}
+
+
+def test_to_openqasm():
+    c = tc.Circuit(3)
+    c.H(0)
+    c.rz(2, theta=0.2)
+    c.cnot(2, 1)
+    c.rzz(0, 1, theta=-1.0)
+    c.ccx(1, 2, 0)
+    print(c.to_openqasm(formatted=True))
